====================
*XSON* Release Notes
====================

1.0.1
=====

Summary of changes:

* Install instructions include pip.
* Automatic SemVer with the help of setuptools_scm.


1.0.0
=====

First release of *XSON*.

Summary of main features:

* Object serialization to and deserialization from JSONx XML documents.
* API-compatibility with the standard JSON package.
* Python 3 implementation.
